# frozen_string_literal: true

execute 'ip6tables-restore < /etc/iptables/general.ipv6' do
  action :nothing
end

directory '/etc/iptables'

rules = []

node['sanitize']['accept_interfaces'].to_hash.each do |iface, allow|
  rules << "-A INPUT -i #{iface} -j ACCEPT" if allow
end

node['sanitize']['ports'].to_hash.each do |port, allows|
  dst_opt = case port
            when Integer then "--dport #{port}"
            when /[,:]/  then "-m multiport --dports #{port}"
            else              "--dport #{Socket.getservbyname(port.to_s)}"
            end
  rules << "-A INPUT -p tcp -m tcp #{dst_opt} -j ACCEPT" \
    if Array(allows).include?(true)
end

rules.sort!

file '/etc/iptables/general.ipv6' do
  mode 0o640
  notifies :run, 'execute[ip6tables-restore < /etc/iptables/general.ipv6]'
  content <<~EOF
    # Generated by Chef for #{node.name}
    *filter
    :INPUT ACCEPT [0:0]
    :FORWARD ACCEPT [0:0]
    :OUTPUT ACCEPT [0:0]
    -A INPUT -m state --state RELATED,ESTABLISHED -j ACCEPT
    -A INPUT -p icmp -j ACCEPT
    #{rules.join("\n")}
    -A INPUT -p tcp -m tcp --tcp-flags SYN,RST,ACK SYN -j REJECT --reject-with icmp6-port-unreachable
    -A INPUT -p udp -j REJECT --reject-with icmp6-port-unreachable
    COMMIT
EOF
end

file '/etc/network/if-pre-up.d/ip6tables_load' do
  content <<~EOF
    #!/bin/sh
    /sbin/ip6tables-restore < /etc/iptables/general.ipv6
    exit 0
EOF
  mode 0o755
end
